The Wikipedia extension - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# The Wikipedia extension

The `wikipedia` extension enriches your ancestry and site with content from Wikipedia.

Enable this extension in your project’s configuration file as follows:

YAML

    extensions:
      wikipedia: {}

JSON

    {
      "extensions": {
        "wikipedia": {}
      }
    }

## Configuration

This extension is configurable:

YAML

    extensions:
      wikipedia:
        configuration:
          populate_images: false

JSON

    {
      "extensions": {
        "wikipedia": {
          "configuration" : {
            "populate_images": false
          }
        }
      }
    }

### `populate_images`

optional

A boolean indicating whether to download images from the Wikipedia links in the ancestry. Defaults to `true`.

## Links

For the extension to know where to look for information, simply add a single link to a human-readable Wikipedia page to that entity’s links.

## Ancestry enrichment

The extension will attempt the following for any entity that has a Wikipedia link:

- for places, add coordinates if a place has none already

- for any entity, add additional links to the translations of the given Wikipedia page

- for any entity that has files, add the primary image of the linked Wikipedia page